@@ -1,6 +1,6 @@
 package Statocles;
 # ABSTRACT: A static site generator
-$Statocles::VERSION = '0.013';
+$Statocles::VERSION = '0.014';
 # This module exists for both documentation and to help File::Share
 # find the right share dir
 
@@ -16,7 +16,7 @@ Statocles - A static site generator
 
 =head1 VERSION
 
-version 0.013
+version 0.014
 
 =head1 DESCRIPTION
 
@@ -24,6 +24,53 @@ Statocles is an application for building static web pages from a set of plain
 YAML and Markdown files. It is designed to make it as simple as possible to
 develop rich web content using basic text-based tools.
 
+=head2 FEATURES
+
+=over
+
+=item *
+
+A simple format combining YAML and Markdown for editing site content.
+
+=item *
+
+A command-line application for building, deploying, and editing the site.
+
+=item *
+
+A L<blogging application|Statocles::App::Blog#FEATURES> with
+
+=over
+
+=item *
+
+RSS and Atom syndication feeds.
+
+=item *
+
+Tags to organize blog posts. Tags have their own custom feeds.
+
+=item *
+
+Crosspost links to direct users to a syndicated blog.
+
+=item *
+
+Post-dated blog posts to appear automatically when the date is passed.
+
+=back
+
+=item *
+
+Customizable L<templates|Statocles::Template> using L<the Mojolicious template
+language|Mojo::Template#SYNTAX>.
+
+=item *
+
+A clean default theme using L<Twitter Bootstrap|http://getbootstrap.com>.
+
+=back
+
 =head1 GUIDES
 
 =head2 GETTING STARTED
@@ -71,6 +118,10 @@ post, for example.
 This page renders a list of other pages (not documents). This is used for index
 pages.
 
+=item L<Statocles::Page::Feed>
+
+This page renders an alternate version of a list page, like an RSS or Atom feed.
+
 =back
 
 =head1 APPLICATIONS
